@@ -30,6 +30,7 @@
 from __future__ import division, absolute_import, print_function, unicode_literals
 
 import codecs
+from distutils.spawn import find_executable
 import datetime
 import os
 import logging
@@ -71,7 +72,6 @@ __all__ = (
     "build_classmap",
     "postprocess",
     "create_dirs",
-    "write_mapping_to_php",
     "create_jinja_environment",
     )
 
@@ -105,8 +105,6 @@ class Context(object):
         # Output options
         'man_pages',
         'qhp',
-        'searchengine',
-        'api_searchbox',
         # Binaries
         'doxygen',
         'qhelpgenerator',
@@ -120,8 +118,6 @@ class Context(object):
         # Output options
         self.man_pages = args.man_pages
         self.qhp = args.qhp
-        self.searchengine = args.searchengine
-        self.api_searchbox = args.api_searchbox
         # Binaries
         self.doxygen = args.doxygen
         self.qhelpgenerator = args.qhelpgenerator
@@ -136,16 +132,15 @@ def create_jinja_environment(doxdatadir):
     return jinja2.Environment(loader=loader)
 
 
-def process_toplevel_html_file(outputfile, doxdatadir, products, title,
-                               api_searchbox=False):
+def process_toplevel_html_file(outputfile, doxdatadir, products, title, qch_enabled=False):
 
     products.sort(key=lambda x: x.fancyname.lower())
     mapping = {
             'resources': './resources',
-            'api_searchbox': api_searchbox,
             # steal the doxygen css from one of the frameworks
             # this means that all the doxygen-provided images etc. will be found
             'title': title,
+            'qch': qch_enabled,
             'breadcrumbs': {
                 'entries': [
                     {
@@ -166,14 +161,13 @@ def process_toplevel_html_file(outputfile, doxdatadir, products, title,
         outf.write(tmpl2.render(mapping))
 
 
-def process_subgroup_html_files(outputfile, doxdatadir, groups, available_platforms, title,
-                                api_searchbox=False):
+def process_subgroup_html_files(outputfile, doxdatadir, groups, available_platforms, title, qch_enabled=False):
 
     for group in groups:
         mapping = {
             'resources': '../resources',
-            'api_searchbox': api_searchbox,
             'title': title,
+            'qch': qch_enabled,
             'breadcrumbs': {
                 'entries': [
                     {
@@ -494,37 +488,6 @@ def build_classmap(tagfile):
     return mapping
 
 
-def write_mapping_to_php(mapping, outputfile, varname='map'):
-    """Write a mapping out as PHP code
-
-    Creates a PHP array as described by mapping.  For example, the mapping
-
-        [("foo","bar"),("x","y")]
-
-    would cause the file
-
-        <?php $map = array('foo' => 'bar','x' => 'y') ?>
-
-    to be written out.
-
-    Args:
-        mapping:    a list of pairs of strings
-        outputfile: the file to write to
-        varname:    override the PHP variable name (defaults to 'map')
-    """
-    logging.info('Generating PHP mapping')
-    with codecs.open(outputfile, 'w', 'utf-8') as f:
-        f.write('<?php $' + varname + ' = array(')
-        first = True
-        for entry in mapping:
-            if first:
-                first = False
-            else:
-                f.write(',')
-            f.write("'" + entry['classname'] + "' => '" + entry['filename'] + "'")
-        f.write(') ?>')
-
-
 def generate_dependencies_page(tmp_dir, doxdatadir, modulename, dependency_diagram):
     """Create `modulename`-dependencies.md in `tmp_dir`"""
     template_path = os.path.join(doxdatadir, 'dependencies.md.tmpl')
@@ -623,8 +586,6 @@ def generate_apidocs(ctx, tmp_dir, doxyfile_entries=None, keep_temp_dirs=False):
                 GENERATE_MAN=ctx.man_pages,
                 GENERATE_QHP=ctx.qhp)
 
-                #, SEARCHENGINE=ctx.searchengine)
-
         if doxyfile_entries:
             writer.write_entries(**doxyfile_entries)
 
@@ -647,7 +608,6 @@ def postprocess(ctx, classmap, template_mapping=None):
             'title': ctx.title,
             'fwinfo': ctx.fwinfo,
             'copyright': ctx.copyright,
-            'api_searchbox': ctx.api_searchbox,
             'doxygen_menu': {'entries': menu_items(ctx.htmldir, ctx.modulename)},
             'class_map': {'classes': classmap},
             'kapidox_version': utils.get_kapidox_version(),
@@ -709,6 +669,9 @@ def create_fw_context(args, lib, tagfiles, copyright=''):
     if lib.part_of_group:
         corrected_tagfiles = []
         for k in range(len(tagfiles)):
+            # tagfiles are tupples like:
+            # ('/usr/share/doc/qt/KF5Completion.tags', '/usr/share/doc/qt')
+            # ('/where/the/tagfile/is/Name.tags', '/where/the/root/folder/is')
             if tagfiles[k][1].startswith("http://") or tagfiles[k][1].startswith("https://"):
                 corrected_tagfiles.append(tagfiles[k])
             else:
@@ -756,7 +719,6 @@ def create_fw_tagfile_tuple(lib):
 
 def finish_fw_apidocs(ctx, group_menu):
     classmap = build_classmap(ctx.tagfile)
-    #write_mapping_to_php(classmap, os.path.join(ctx.outputdir, 'classmap.inc'))
 
     entries = [{
         'href': '../../index.html',
@@ -780,12 +742,12 @@ def finish_fw_apidocs(ctx, group_menu):
                 }
     copyright = '1996-' + str(datetime.date.today().year) + ' The KDE developers'
     mapping = {
+            'qch': ctx.qhp,
             'doxygencss': 'doxygen.css',
             'resources': ctx.resourcedir,
             'title': ctx.title,
             'fwinfo': ctx.fwinfo,
             'copyright': copyright,
-            'api_searchbox': ctx.api_searchbox,
             'doxygen_menu': {'entries': menu_items(ctx.htmldir, ctx.modulename)},
             'class_map': {'classes': classmap},
             'kapidox_version': utils.get_kapidox_version(),
@@ -921,7 +883,6 @@ def create_qch(products, tagfiles):
                 child.attrib['ref'] = product.name + '/' +child.attrib['ref']
 
             for child in root.find(".//"+tag_toc):
-                print(child.attrib['ref'])
                 if lib.part_of_group:
                     product_indexSection.append(child)
                 else:
@@ -933,16 +894,6 @@ def create_qch(products, tagfiles):
             resources = [
                 "*.json",
                 product.name + "/*.json",
-                product.name +"/" + lib.name +"/html/*.json",
-                product.name + "/*.html",
-                product.name + "/html/*.html",
-                product.name +"/html/*.png",
-                product.name +"/html/*.css",
-                product.name +"/html/*.js",
-                product.name +"/" + lib.name +"/html/*.html",
-                product.name +"/" + lib.name +"/html/*.png",
-                product.name +"/" + lib.name +"/html/*.css",
-                product.name +"/" + lib.name +"/html/*.js",
                 "resources/css/*.css",
                 "resources/3rd-party/bootstrap/css/*.css",
                 "resources/3rd-party/jquery/jquery-3.1.0.min.js",
@@ -950,6 +901,24 @@ def create_qch(products, tagfiles):
                 "resources/js/*.js",
                 "resources/icons/*",
             ]
+            if product.part_of_group:
+                resources.extend([
+                    product.name + "/*.html",
+                    product.name + "/" + lib.name +"/html/*.html",
+                    product.name + "/" + lib.name +"/html/*.png",
+                    product.name + "/" + lib.name +"/html/*.css",
+                    product.name + "/" + lib.name +"/html/*.js",
+                    product.name + "/" + lib.name +"/html/*.json"
+                    ])
+
+            else:
+                resources.extend([
+                    product.name + "/html/*.html",
+                    product.name + "/html/*.png",
+                    product.name + "/html/*.css",
+                    product.name + "/html/*.js"
+                    ])
+
             for resource in resources:
                 file_elem = ET.SubElement(files, "file")
                 file_elem.text = resource
@@ -960,5 +929,14 @@ def create_qch(products, tagfiles):
         name = product.name+".qhp"
         outname = product.name+".qch"
         tree_out.write(name, encoding="utf-8", xml_declaration=True)
-        subprocess.call(["qhelpgenerator", name, '-o', 'qch/'+outname])
+
+        # On many distributions, qhelpgenerator from Qt5 is suffixed with
+        # "-qt5". Look for it first, and fall back to unsuffixed one if
+        # not found.
+        qhelpgenerator = find_executable("qhelpgenerator-qt5")
+
+        if qhelpgenerator is None:
+            qhelpgenerator = "qhelpgenerator"
+
+        subprocess.call([qhelpgenerator, name, '-o', 'qch/'+outname])
         os.remove(name)
